function neighbors = collectNeighborsKd(X, dist)
%COLLECTNEIGHBORSKD Find neighboring vertices using a k-d tree.
%
%   COLLECTNEIGHBORSKD(X, DIST) collects all neighboring vertices of the N
%   vertices in the Xx3 coordinate matrix X. Vertices are neighboring if
%   their maximum coordinate difference is smaller than DIST (L-infinity
%   norm).
%
%   Contact person:
%     Falko Schindler (falko.schindler@uni-bonn.de)
%
%   Copyright 2011-2012

%% build k-d tree
tree = kdtree(X);

%% define range for neighborhoods
range = dist * [-1, 1; -1, 1; -1, 1];

%% collect neighbors
neighbors = cell(1, size(X, 1));
for i = 1 : size(X, 1)
    neighbors{i} = kdtree_range(tree, X([i i], :)' + range);
end
