function plotBoundaries(f, X, TRI, label)
%PLOTBOUNDARIES Plot boundaris of segmentation LABEL.
%
%   Given a figure handle F, a Nx3 vertex coordinate matrix X, a Tx3
%   triangulation matrix TRI and a Nx1 labeling LABEL, draw the boundaries
%   between vertices of different label. Note that triangles can be
%   possibly split into two or three regions of different label.
%
%   In case the hande F is possitive, the figure F is cleared and both axes
%   and view are re-initialized. If F is negative, the boundary is drawn on
%   top of previous plots.
%
%   Contact person:
%     Falko Schindler (falko.schindler@uni-bonn.de)
%
%   Copyright 2011-2012

%% prepare figure
figure(abs(f));
if f > 0, clf; axis equal off; view(3); hold on; end
set(gca, 'Projection', 'perspective');

%% plot edges separating three unequally labeled points
E1 = (X(TRI(:, 2), :) + X(TRI(:, 3), :)) / 2;
E2 = (X(TRI(:, 3), :) + X(TRI(:, 1), :)) / 2;
E3 = (X(TRI(:, 1), :) + X(TRI(:, 2), :)) / 2;
M = (X(TRI(:, 1), :) + X(TRI(:, 2), :) + X(TRI(:, 3), :)) / 3;
sel = label(TRI(:, 2)) ~= label(TRI(:, 3)) & ...
      label(TRI(:, 3)) ~= label(TRI(:, 1)) & ...
      label(TRI(:, 1)) ~= label(TRI(:, 2));
plot3([E1(sel, 1) M(sel, 1)]', [E1(sel, 2) M(sel, 2)]', [E1(sel, 3) M(sel, 3)]', 'k-', 'LineWidth', 3);
plot3([E2(sel, 1) M(sel, 1)]', [E2(sel, 2) M(sel, 2)]', [E2(sel, 3) M(sel, 3)]', 'k-', 'LineWidth', 3);
plot3([E3(sel, 1) M(sel, 1)]', [E3(sel, 2) M(sel, 2)]', [E3(sel, 3) M(sel, 3)]', 'k-', 'LineWidth', 3);

%% plot edges separating unequally labeled points
for k = 1 : 3
    TRI = circshift(TRI, [0 1]);
    E1 = (X(TRI(:, 2), :) + X(TRI(:, 3), :)) / 2;
    E2 = (X(TRI(:, 3), :) + X(TRI(:, 1), :)) / 2;
    sel = label(TRI(:, 2)) ~= label(TRI(:, 3)) & ...
          label(TRI(:, 3)) ~= label(TRI(:, 1)) & ...
          label(TRI(:, 1)) == label(TRI(:, 2));
    plot3([E1(sel, 1) E2(sel, 1)]', [E1(sel, 2) E2(sel, 2)]', [E1(sel, 3) E2(sel, 3)]', 'k-', 'LineWidth', 3);
end
