function plotMesh(f, X, TRI, color)
%PLOTMESH Plot triangulated mesh with coordinates X and triangulation TRI.
%
%   Given a figure handle F, a Nx3 vertex coordinate matrix X and a Tx3
%   triangulation matrix TRI, draw the triangulated surface.
%
%   In case the hande F is possitive, the figure F is cleared and both axes
%   and view are re-initialized. If F is negative, the boundary is drawn on
%   top of previous plots.
%
%   Contact person:
%     Falko Schindler (falko.schindler@uni-bonn.de)
%
%   Copyright 2011-2012

%% prepare figure
figure(abs(f));
if f > 0, clf; axis equal off; view(3); hold on; end
set(gca, 'Projection', 'perspective');

%% plot mesh
if ~exist('color', 'var')
    varargs = {'FaceColor', 0.75 * [1 1 1]};
else
    if islogical(color)
        color = 0.75 * [~color(:), color(:), zeros(numel(color), 1)];
    end
    varargs = {'FaceVertexCData', color};
end
trisurf(TRI, X(:, 1), X(:, 2), X(:, 3), 'EdgeColor', 'none', varargs{:});
material dull
light('Position', [ 1  1 1], 'Style', 'infinite');
light('Position', [-1 -1 1], 'Style', 'infinite');
