function [vertex, face] = read_off(filename)
%READ_OFF Read triangulation from OFF-file FILENAME.
%
%   Given the FILENAME of a OFF-file (Object File Format) load vertices and
%   faces. The resulting Tx3 matrix FACES contains triangles, i.e. three
%   vertex indices each. The vertex coordinate matrix VERTEX is of size
%   Nx3.
%
%   Contact person:
%     Falko Schindler (falko.schindler@uni-bonn.de)
%
%   Copyright 2011-2012

%% open file
fid = fopen(filename, 'r');
if fid < 0, error('Can''t open the file.'); end

%% check header
str = fgets(fid);
if ~strcmp(str(1 : 3), 'OFF'), error('Not a valid OFF file.'); end

%% read dimensions
str = fgets(fid);
[a, str] = strtok(str);
nvert = str2double(a);
a = strtok(str);
nface = str2double(a);

%% read vertices
[A, cnt] = fscanf(fid, '%f %f %f', 3 * nvert);
if cnt ~= 3 * nvert
    warning('Problem in reading vertices.'); %#ok<WNTAG>
end
vertex = reshape(A, 3, [])';

%% read faces
[A, cnt] = fscanf(fid, '%d %d %d %d\n', 4 * nface);
if cnt ~= 4 * nface
    warning('Problem in reading faces.'); %#ok<WNTAG>
end
A = reshape(A, 4, []);
face = uint32(A(2 : 4, :)' + 1);

%% close file
fclose(fid);

